@@ -9,10 +9,14 @@ class Command(RunserverCommand):
 
     def add_arguments(self, parser):
         super(Command, self).add_arguments(parser)
-        parser.add_argument('--nostatic', action="store_false", dest='use_static_handler', default=True,
-            help='Tells Django to NOT automatically serve static files at STATIC_URL.')
-        parser.add_argument('--insecure', action="store_true", dest='insecure_serving', default=False,
-            help='Allows serving static files even if DEBUG is False.')
+        parser.add_argument(
+            '--nostatic', action="store_false", dest='use_static_handler', default=True,
+            help='Tells Django to NOT automatically serve static files at STATIC_URL.',
+        )
+        parser.add_argument(
+            '--insecure', action="store_true", dest='insecure_serving', default=False,
+            help='Allows serving static files even if DEBUG is False.',
+        )
 
     def get_handler(self, *args, **options):
         """
@@ -21,8 +25,8 @@ class Command(RunserverCommand):
         handler.
         """
         handler = super(Command, self).get_handler(*args, **options)
-        use_static_handler = options.get('use_static_handler', True)
-        insecure_serving = options.get('insecure_serving', False)
+        use_static_handler = options['use_static_handler']
+        insecure_serving = options['insecure_serving']
         if use_static_handler and (settings.DEBUG or insecure_serving):
             return StaticFilesHandler(handler)
         return handler
